Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/displayio_layout_simpletest.py
    :caption: examples/displayio_layout_simpletest.py
    :linenos:

GridLayout divider lines example
--------------------------------

Create GridLayouts with divider lines.

.. literalinclude:: ../examples/displayio_layout_gridlayout_dividers.py
    :caption: examples/displayio_layout_gridlayout_dividers.py
    :linenos:

Pygame simple test
------------------

Display Hello World using Blinka_Displayio_PyGameDisplay.

.. literalinclude:: ../examples/displayio_layout_gridlayout_pygame_display_simpletest.py
    :caption: examples/displayio_layout_gridlayout_pygame_display_simpletest.py
    :linenos:

Switch simple test
------------------

Create a single sliding switch.

.. literalinclude:: ../examples/displayio_layout_switch_simpletest.py
    :caption: examples/displayio_layout_switch_simpletest.py
    :linenos:

Switch test with multiple switches
----------------------------------

Create multiple sliding switch with various sizes and orientations.

.. literalinclude:: ../examples/displayio_layout_switch_multiple.py
    :caption: examples/displayio_layout_switch_multiple.py
    :linenos:

FlipInput simple test
---------------------

Create three FlipInput selectors.

.. literalinclude:: ../examples/displayio_layout_flip_input_simpletest.py
    :caption: examples/displayio_layout_flip_input_simpletest.py
    :linenos:

Cartesian plane simple test
---------------------------

Create a simple plot plane.

.. literalinclude:: ../examples/displayio_layout_cartesian_simpletest.py
    :caption: examples/displayio_layout_cartesian_simpletest.py
    :linenos:
